@@ -1,5 +1,5 @@
 import logging
-from .utils import file_filters
+from .utils import file_filters, convert_dict_keys
 from .helpers import JobStatus
 from .event_id import EventID
 
@@ -26,6 +26,11 @@ class BilbyJob:
         Job name
     description : str
         Job description
+    user : str
+        User that ran the job
+    event_id : dict
+        Event ID associated with job, should have keys corresponding to an
+        :class:`~.EventID` object
     job_status : dict
         Status of job, should have 'name' and 'date' keys corresponding to the status code and when it was produced
     kwargs : dict, optional
@@ -39,11 +44,13 @@ class BilbyJob:
         'corner_plot': file_filters.corner_plot_filter,
     }
 
-    def __init__(self, client, job_id, name, description, job_status, **kwargs):
+    def __init__(self, client, job_id, name, description, user, event_id, job_status, **kwargs):
         self.client = client
         self.job_id = job_id
         self.name = name
         self.description = description
+        self.user = user
+        self.event_id = EventID(**event_id) if event_id else None
         self.status = JobStatus(status=job_status['name'], date=job_status['date'])
         self.other = kwargs
         self.is_uploaded_job = None
@@ -62,42 +69,6 @@ class BilbyJob:
         result, self.is_uploaded_job = self.client._get_files_by_job_id(self.job_id)
         return result
 
-    def get_files_by_reference(self, file_references):
-        """Obtain the data for a FileReferenceList
-
-        Parameters
-        ----------
-        file_references : .FileReferenceList
-            Contains FileReference instances for each of the files to be downloaded
-
-        Returns
-        -------
-        list
-            List of tuples with the file path and downloaded file contents as a byte string
-        """
-        return self.client._get_files_by_reference(self.job_id, file_references, self.is_uploaded_job)
-
-    def save_files_by_reference(self, file_references, root_path, preserve_directory_structure=True):
-        """Save the files represented in a FileReferenceList
-
-        Parameters
-        ----------
-        file_references : .FileReferenceList
-            Contains FileReference instances for each of the files to be downloaded and saved
-        root_path : str or ~pathlib.Path
-            Directory into which to save the files
-        preserve_directory_structure : bool, optional
-            Whether or not the files should retain the directory structure in which they are downloaded, by default True
-
-        Returns
-        -------
-        str
-            Success message
-        """
-        return self.client._save_files_by_reference(
-            self.job_id, file_references, root_path, preserve_directory_structure, self.is_uploaded_job
-        )
-
     @classmethod
     def register_file_list_filter(cls, name, file_list_filter_fn):
         """Register a function used to filter the file list.
@@ -119,14 +90,7 @@ class BilbyJob:
         _register_file_list_filter(name, file_list_filter_fn)
         cls.DEFAULT_FILE_LIST_FILTERS[f'{name}'] = file_list_filter_fn
 
-    def set_event_id(self, event_id=None):
-        """Set the Event ID of a Bilby Job
-
-        Parameters
-        ----------
-        event_id : EventID or str
-            The desired Event ID, by default None
-        """
+    def _update_job(self, **kwargs):
         query = """
             mutation BilbyJobEventIDMutation($input: UpdateBilbyJobMutationInput!) {
                 updateBilbyJob(input: $input) {
@@ -135,6 +99,50 @@ class BilbyJob:
             }
         """
 
+        variables = {
+            "input": {
+                "jobId": self.job_id,
+                **convert_dict_keys(kwargs, reverse=True)
+            }
+        }
+
+        return self.client.request(query=query, variables=variables)
+
+    def set_name(self, name):
+        """Set the name of a Bilby Job
+
+        Parameters
+        ----------
+        event_id : str
+            The new name
+        """
+
+        data = self._update_job(name=str(name))
+        self.name = name
+        logger.info(data['updateBilbyJob']['result'])
+
+    def set_description(self, description):
+        """Set the description of a Bilby Job
+
+        Parameters
+        ----------
+        event_id : str
+            The new description
+        """
+
+        data = self._update_job(description=str(description))
+        self.description = description
+        logger.info(data['updateBilbyJob']['result'])
+
+    def set_event_id(self, event_id=None):
+        """Set the Event ID of a Bilby Job
+
+        Parameters
+        ----------
+        event_id : EventID or str, optional
+            The desired Event ID, by default None
+        """
+
         if isinstance(event_id, EventID):
             new_event_id = event_id.event_id
         elif isinstance(event_id, str):
@@ -144,15 +152,8 @@ class BilbyJob:
         else:
             raise Exception('Parameter event_id must be an EventID, a string or None')
 
-        variables = {
-            "input": {
-                "jobId": self.job_id,
-                "eventId": new_event_id
-            }
-        }
-
-        data = self.client.request(query=query, variables=variables)
-        self.other['event_id'] = self.client.get_event_id(event_id=new_event_id)
+        data = self._update_job(event_id=new_event_id)
+        self.event_id = self.client.get_event_id(event_id=new_event_id)
         logger.info(data['updateBilbyJob']['result'])
 
 
@@ -176,7 +177,7 @@ def _register_file_list_filter(name, file_list_filter_fn):
 
     def _get_files(self):
         file_list = _get_file_list_subset(self)
-        return self.get_files_by_reference(file_list)
+        return self.client.get_files_by_reference(file_list)
 
     files_fn_name = f'get_{name}_files'
     files_fn = _get_files
@@ -195,7 +196,7 @@ def _register_file_list_filter(name, file_list_filter_fn):
 
     def _save_files(self, root_path, preserve_directory_structure=True):
         file_list = _get_file_list_subset(self)
-        return self.save_files_by_reference(file_list, root_path, preserve_directory_structure)
+        return self.client.save_files_by_reference(file_list, root_path, preserve_directory_structure)
 
     save_fn_name = f'save_{name}_files'
     save_fn = _save_files
